==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/EQUIPMENTINFO_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour EQUIPMENTINFO_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EQUIPMENTINFO_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTDETAILID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OBJTYPE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EQUIPMENTINFO_Type", propOrder = {
    "equipmentdetailid",
    "objtype"
})
public class EQUIPMENTINFO_Type {

    @XmlElement(name = "EQUIPMENTDETAILID", required = true)
    protected OBJECT_Type equipmentdetailid;
    @XmlElement(name = "OBJTYPE", required = true)
    protected String objtype;

    /**
     * Obtient la valeur de la propriété equipmentdetailid.
     * 
     * @return
     *     possible object is
     *     {@link OBJECT_Type }
     *     
     */
    public OBJECT_Type getEQUIPMENTDETAILID() {
        return equipmentdetailid;
    }

    /**
     * Définit la valeur de la propriété equipmentdetailid.
     * 
     * @param value
     *     allowed object is
     *     {@link OBJECT_Type }
     *     
     */
    public void setEQUIPMENTDETAILID(OBJECT_Type value) {
        this.equipmentdetailid = value;
    }

    /**
     * Obtient la valeur de la propriété objtype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOBJTYPE() {
        return objtype;
    }

    /**
     * Définit la valeur de la propriété objtype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOBJTYPE(String value) {
        this.objtype = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/EQUIPMENTINFO_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for EQUIPMENTINFO_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="EQUIPMENTINFO_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTDETAILID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OBJTYPE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EQUIPMENTINFO_Type", propOrder = {
    "equipmentdetailid",
    "objtype"
})
public class EQUIPMENTINFO_Type {

    @XmlElement(name = "EQUIPMENTDETAILID", required = true)
    protected OBJECT_Type equipmentdetailid;
    @XmlElement(name = "OBJTYPE", required = true)
    protected String objtype;

    /**
     * Gets the value of the equipmentdetailid property.
     * 
     * @return
     *     possible object is
     *     {@link OBJECT_Type }
     *     
     */
    public OBJECT_Type getEQUIPMENTDETAILID() {
        return equipmentdetailid;
    }

    /**
     * Sets the value of the equipmentdetailid property.
     * 
     * @param value
     *     allowed object is
     *     {@link OBJECT_Type }
     *     
     */
    public void setEQUIPMENTDETAILID(OBJECT_Type value) {
        this.equipmentdetailid = value;
    }

    /**
     * Gets the value of the objtype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOBJTYPE() {
        return objtype;
    }

    /**
     * Sets the value of the objtype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOBJTYPE(String value) {
        this.objtype = value;
    }

}
